@@ -1,8 +1,8 @@
 """Test simple execution"""
 
 
-def test_can_pass(testdir):
-    testdir.makepyfile(
+def test_can_pass(pytester):
+    pytester.makepyfile(
         """
         def describe_something():
             def passes():
@@ -10,14 +10,15 @@ def test_can_pass(testdir):
             def describe_nested():
                 def passes_too():
                     assert True
-        """)
+        """
+    )
 
-    result = testdir.runpytest()
+    result = pytester.runpytest()
     result.assert_outcomes(passed=2)
 
 
-def test_can_fail(testdir):
-    testdir.makepyfile(
+def test_can_fail(pytester):
+    pytester.makepyfile(
         """
         def describe_something():
             def fails():
@@ -25,14 +26,15 @@ def test_can_fail(testdir):
             def describe_nested():
                 def fails_too():
                     assert False
-        """)
+        """
+    )
 
-    result = testdir.runpytest()
+    result = pytester.runpytest()
     result.assert_outcomes(failed=2)
 
 
-def test_can_fail_and_pass(testdir):
-    testdir.makepyfile(
+def test_can_fail_and_pass(pytester):
+    pytester.makepyfile(
         """
         def describe_something():
             def describe_nested_ok():
@@ -41,7 +43,8 @@ def test_can_fail_and_pass(testdir):
             def describe_nested_bad():
                 def fails():
                     assert False
-        """)
+        """
+    )
 
-    result = testdir.runpytest()
+    result = pytester.runpytest()
     result.assert_outcomes(passed=1, failed=1)
